DummyHitbox class
- Inheritance
-
- Object
- BoundingHitbox
- DummyHitbox
- Available extensions
Constructors
Properties
- aabb → Aabb2
-
The axis-aligned bounding box of the
Hitbox, this is used to make a rough estimation of whether two hitboxes can possibly collide or not.no setterinherited - aabbCenter ↔ Vector2
-
aabbcalculates center at each call. This method provides caching.getter/setter pairinherited - aabbCenter → Vector2
-
Available on ShapeHitbox, provided by the SpatialGridShapeHitbox extension
no setter - aabbCenter → Vector2
-
Available on RectangleHitbox, provided by the SpatialGridRectangleHitbox extension
no setter - absoluteAngle → double
-
The resulting angle after all the ancestors and the components own angles
and scales have been applied.
no setterinherited
- absoluteAngleWithoutReflection → double
-
The resulting angle after all the ancestors and the components own angles
and scales have been applied, but without reflecting the angle
if the component is flipped.
no setterinherited
- absoluteCenter → Vector2
-
The absolute center of the component.
no setterinherited
- absolutePosition → Vector2
-
The
anchor's position in absolute (world) coordinates.no setterinherited - absoluteScale → Vector2
-
The resulting scale after all the ancestors and the components own scale
has been applied.
no setterinherited
- absoluteScaledSize → Vector2
-
The resulting size after all the ancestors and the components own scale
has been applied.
no setterinherited
- absoluteTopLeftPosition → Vector2
-
The absolute top left position regardless of whether it is a child or not.
no setterinherited
-
activeCollisions
→ Set<
ShapeHitbox> -
The objects that the object is currently colliding with.
no setterinherited
- allowSiblingCollision ↔ bool
-
Whether the hitbox is allowed to collide with another hitbox that is
added to the same parent.
getter/setter pairinherited
- anchor ↔ Anchor
-
Anchor point for this component. An anchor point describes a point
within the rectangle of size
size. This point is considered to be the logical "center" of the component. This can be visualized as the point where Flame "grabs" the component. All transforms occur around this point: thepositionis where the anchor point will end up after the component is translated; the rotation and scaling also happen around this anchor point.getter/setter pairinherited - angle ↔ double
-
Rotation angle (in radians) of the component. The component will be
rotated around its anchor point in the clockwise direction if the
angle is positive, or counterclockwise if the angle is negative.
getter/setter pairinherited
- cacheAbsoluteAngle ↔ bool
-
getter/setter pairinherited
- cacheAbsoluteScaledSize ↔ bool
-
getter/setter pairinherited
- canBeActive ↔ bool
-
getter/setter pairinherited
- canBeActive → bool
-
Available on PositionComponent, provided by the PositionComponentWithGridSupport extension
no setter - canBeActive → bool
-
Available on ShapeHitbox, provided by the SpatialGridShapeHitbox extension
no setter - center ↔ Vector2
-
The position of the center of the component's bounding rectangle
in the parent's coordinates.
getter/setter pairinherited
-
children
→ ReadOnlyOrderedSet<
Component> -
The children components of this component.
no setterinherited
- collisionCheckFrequency ↔ double
-
getter/setter pairinherited
- collisionType ↔ CollisionType
-
Whether the hitbox should:
getter/setter pairinherited
- debugColor ↔ Color
-
getter/setter pairinherited
- debugCoordinatesPrecision ↔ int?
-
How many decimal digits to print when displaying coordinates in the
debug mode. Setting this to null will suppress all coordinates from
the output.
getter/setter pairinherited
- debugMode ↔ bool
-
Returns whether this
Componentis in debug mode or not. When a child is added to theComponentit gets the samedebugModeas its parent has when it is prepared.getter/setter pairinherited - debugPaint → Paint
-
The
debugColorrepresented as a Paint object.no setterinherited - debugTextPaint → TextPaint
-
Returns a
TextPaintobject with thedebugColorset as color for the text.no setterinherited - decorator ↔ Decorator
-
The decorator is used to apply visual effects to a component.
getter/setter pairinherited
- defaultCollisionType ↔ CollisionType
-
Every hitbox changes it's
collisionTypeduring Cell's lifetime. It can conditionally becomeCollisionType.inactive, for example. defaultCollisionType is used to restore right state after inactivation.getter/setter pairinherited - defaultCollisionType ↔ CollisionType
-
Available on ShapeHitbox, provided by the SpatialGridShapeHitbox extension
getter/setter pair - doExtendedTypeCheck → bool
-
Available on ShapeHitbox, provided by the SpatialGridShapeHitbox extension
no setter - doExtendedTypeCheck ↔ bool
-
getter/setter pairinherited
- fastCollisionForRects ↔ bool
-
getter/setter pairinherited
-
game
↔ HasSpatialGridFramework<
World> -
Reference to the top-level Game instance that owns this component.
getter/setter pairinherited
- group → GroupHitbox?
-
no setterinherited
- groupAbsoluteCacheByType ↔ bool
-
getter/setter pairinherited
-
groupCollisionsTags
→ List<
String> -
finalinherited
- hasChildren → bool
-
Whether this component has any children.
Avoids the creation of the children container if not necessary.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPaintLayers → bool
-
Whether there are any paint layers defined for the component.
no setterinherited
- height ↔ double
-
The height of the component in local coordinates. Note that the object
may visually appear larger or smaller due to application of
scale.getter/setter pairinherited - hitboxParent → PositionComponent
-
no setterinherited
- hue ↔ double
-
getter/setter pairinherited
- isColliding → bool
-
Whether the object is currently colliding or not.
no setterinherited
- isDistanceCallbackEnabled ↔ bool
-
getter/setter pairinherited
- isFlippedHorizontally → bool
-
Whether it is currently flipped horizontally.
no setterinherited
- isFlippedVertically → bool
-
Whether it is currently flipped vertically.
no setterinherited
- isLoaded → bool
-
Whether this component has completed its
onLoadstep.no setterinherited - isLoading → bool
-
Whether the component is currently executing its
onLoadstep.no setterinherited - isMounted → bool
-
Whether this component is currently added to a component tree.
no setterinherited
- isRemoved → bool
-
Whether the component has been removed. Originally this flag is
false, but it becomestrueafter the component was mounted and then removed from its parent. The flag becomesfalseagain when the component is mounted to a new parent.no setterinherited - isRemoving → bool
-
Whether the component is scheduled to be removed.
no setterinherited
- isSolid ↔ bool
-
Whether the shape is solid or hollow.
getter/setter pairinherited
- key → ComponentKey?
-
A key that can be used to identify this component in the tree.
finalinherited
-
loaded
→ Future<
void> -
A future that completes when this component finishes loading.
no setterinherited
- macroPosition → Vector2
-
no setterinherited
- macroSize → Vector2
-
no setterinherited
- manuallyPositioned ↔ bool
-
getter/setter pairinherited
-
mounted
→ Future<
void> -
A future that will complete once the component is mounted on its parent.
no setterinherited
- nativeAngle ↔ double
-
The angle where this component is looking at when it is in
the default state, i.e. when
angleis equal to zero. For example, a nativeAngle of 0 implies up/north direction pi/2 implies right/east direction pi implies down/south direction -pi/2 implies left/west directiongetter/setter pairinherited -
onCollisionCallback
↔ CollisionCallback<
ShapeHitbox> ? -
getter/setter pairinherited
-
onCollisionEndCallback
↔ CollisionEndCallback<
ShapeHitbox> ? -
getter/setter pairinherited
-
onCollisionStartCallback
↔ CollisionCallback<
ShapeHitbox> ? -
getter/setter pairinherited
- opacity ↔ double
-
getter/setter pairinherited
- optimized → bool
-
no setterinherited
- paint ↔ Paint
-
getter/setter pairinherited
-
paintLayers
↔ List<
Paint> -
List of paints to use (in order) during render.
getter/setter pairinherited
- parent ↔ Component?
-
Who owns this component in the component tree.
getter/setter pairinherited
- parentSpeedGetter ↔ double Function()?
-
getter/setter pairinherited
- parentWithGridSupport → HasGridSupport?
-
Parent component which should be with HasGridSupport mixin
no setterinherited
- parentWithGridSupport → HasGridSupport?
-
Available on ShapeHitbox, provided by the SpatialGridShapeHitbox extension
no setter - position ↔ NotifyingVector2
-
The position of this component's anchor on the screen.
getter/setter pairinherited
- priority ↔ int
-
Render priority of this component. This allows you to control the order in
which your components are rendered.
getter/setter pairinherited
-
removed
→ Future<
void> -
A future that completes when this component is removed from its parent.
no setterinherited
- renderContext → ComponentRenderContext?
-
Override this method if you want your component to provide a custom
render context to all its children (recursively).
no setterinherited
- renderShape ↔ bool
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale ↔ NotifyingVector2
-
The scale factor of this component. The scale can be different along
the X and Y dimensions. A scale greater than 1 makes the component
bigger, and less than 1 smaller. The scale can also be negative,
which results in a mirror reflection along the corresponding axis.
getter/setter pairinherited
- scaledSize → Vector2
-
The "physical" size of the component. This is the size of the
component as seen from the parent's perspective, and it is equal to
size*scale. This is a computed property and cannot be modified by the user.no setterinherited - shouldFillParent ↔ bool
-
getter/setter pairinherited
- shrinkToBounds ↔ bool
-
getter/setter pairinherited
- size ↔ NotifyingVector2
-
The logical size of the component. The game assumes that this is the
approximate size of the object that will be drawn on the screen.
This size will therefore be used for collision detection and tap
handling.
getter/setter pairinherited
- topLeftPosition ↔ Vector2
-
The top-left corner's position in the parent's coordinates.
getter/setter pairinherited
- transform → Transform2D
-
finalinherited
- transformMatrix → Matrix4
-
The total transformation matrix for the component. This matrix combines
translation, rotation and scale transforms into a single entity. The
matrix is cached and gets recalculated only as necessary.
no setterinherited
- triggersParentCollision ↔ bool
-
Whether hitbox collisions with other hitboxes should trigger the
"onCollision" functions for the hitbox's parent component.
getter/setter pairinherited
-
vertices
→ UnmodifiableListView<
Vector2> -
no setterinherited
- width ↔ double
-
The width of the component in local coordinates. Note that the object
may visually appear larger or smaller due to application of
scale.getter/setter pairinherited - x ↔ double
-
X position of this component's anchor on the screen.
getter/setter pairinherited
- y ↔ double
-
Y position of this component's anchor on the screen.
getter/setter pairinherited
Methods
-
absoluteAngleCacheReset(
) → void -
inherited
-
absolutePositionOf(
Vector2 point) → Vector2 -
Convert local coordinates of a point
pointinside the component into the global (world) coordinate space.inherited -
absolutePositionOfAnchor(
Anchor anchor) → Vector2 -
Similar to absolutePositionOf(), but applies to any anchor
point within the component.
inherited
-
absoluteScaledSizeCacheReset(
) → void -
inherited
-
absoluteToLocal(
Vector2 point) → Vector2 -
Transform
pointfrom the global (world) coordinate space into the local coordinates. This function is the inverse of absolutePositionOf().inherited -
add(
Component component) → FutureOr< void> -
Schedules
componentto be added as a child to this component.inherited -
addAll(
Iterable< Component> components) → Future<void> -
A convenience method to
addmultiple children at once.inherited -
addToParent(
Component parent) → FutureOr< void> -
Adds this component as a child of
parent(seeaddfor details).inherited -
afterChildrenRendered(
Canvas canvas) → void -
Called once after all children have been rendered in
renderTree.inherited -
ancestors(
{bool includeSelf = false}) → Iterable< Component> -
An iterator producing this component's parent, then its parent's parent,
then the great-grand-parent, and so on, until it reaches a component
without a parent.
inherited
-
angleTo(
Vector2 target) → double -
Returns the angle formed by component's orientation vector and a vector
starting at component's absolute position and ending at
target. I.e. how much the current component need to rotate to face the target. This angle is measured in clockwise direction.targetshould be in absolute/world coordinate system.inherited -
cleanOldKeys(
) → void -
inherited
-
collidingWith(
Hitbox< Hitbox> other) → bool -
Whether the object is colliding with
otheror not.inherited -
componentsAtLocation<
T> (T locationContext, List< T> ? nestedContexts, T? transformContext(CoordinateTransform, T), bool checkContains(Component, T)) → Iterable<Component> -
This is a generic implementation of
componentsAtPoint; refer to those docs for context.inherited -
componentsAtPoint(
Vector2 point, [List< Vector2> ? nestedPoints]) → Iterable<Component> -
An iterable of descendant components intersecting the given point. The
pointis in the local coordinate space.inherited -
computeAabb(
Aabb2 aabb) → void -
Computes the axis-aligned bounding box for this hitbox.
inherited
-
contains(
Component c) → bool -
Whether the children list contains the given component.
inherited
-
containsLocalPoint(
Vector2 point) → bool -
Test whether the
point(given in local coordinates) lies within this component. The top and the left borders of the component are inclusive, while the bottom and the right borders are exclusive.inherited -
containsPoint(
Vector2 point) → bool -
Checks whether the polygon contains the
point. Note: The polygon needs to be convex for this to work.inherited -
createComponentSet(
) → OrderedSet< Component> -
This method creates the children container for the current component.
Override this method if you need to have a custom
OrderedSetwithin a particular class.inherited -
deletePaint(
Object paintId) → void -
Removes a paint from the collection.
inherited
-
descendants(
{bool includeSelf = false, bool reversed = false}) → Iterable< Component> -
Recursively enumerates all nested
children.inherited -
distance(
PositionComponent other) → double -
Measure the distance (in parent's coordinate space) between this
component's anchor and the
othercomponent's anchor.inherited -
fillParent(
) → void -
This determines how the shape should scale if it should try to fill its
parents boundaries.
inherited
-
findGame(
) → FlameGame< World> ? -
Fetches the nearest
FlameGameancestor to the component.inherited -
findParent<
T extends Component> ({bool includeSelf = false}) → T? -
Returns the closest parent further up the hierarchy that satisfies type=T,
or null if no such parent can be found.
inherited
-
findRenderContext<
T extends ComponentRenderContext> () → T? -
inherited
-
findRootGame(
) → FlameGame< World> ? -
Fetches the root
FlameGameancestor to the component.inherited -
firstChild<
T extends Component> () → T? -
Returns the first child that matches the given type
T, or null if there are no such children.inherited -
flipHorizontally(
) → void -
Flip the component horizontally around its anchor point.
inherited
-
flipHorizontallyAroundCenter(
) → void -
Flip the component horizontally around its center line.
inherited
-
flipVertically(
) → void -
Flip the component vertically around its anchor point.
inherited
-
flipVerticallyAroundCenter(
) → void -
Flip the component vertically around its center line.
inherited
-
getAlpha(
{Object? paintId}) → int -
Returns the current opacity.
inherited
-
getBroadphaseCheckCache(
ShapeHitbox item) → bool? -
inherited
-
getBroadphaseCheckCache(
ShapeHitbox item) → bool? -
Available on ShapeHitbox, provided by the SpatialGridShapeHitbox extension
-
getEdge(
int i, {required List< Vector2> vertices}) → LineSegment -
inherited
-
getOpacity(
{Object? paintId}) → double -
Returns the current opacity.
inherited
-
getPaint(
[Object? paintId]) → Paint -
Gets a paint from the collection.
inherited
-
getVertex(
int i, {List< Vector2> ? vertices}) → Vector2 -
inherited
-
globalVertices(
) → List< Vector2> -
gives back the shape vectors multiplied by the size and scale
inherited
-
intersections(
Hitbox< Hitbox> other) → Set<Vector2> -
Where this
ShapeComponenthas intersection points with another shapeinherited -
isFullyInsideRect(
Rect rect) → bool -
Available on RectangleHitbox, provided by the SpatialGridRectangleHitbox extension
-
isFullyInsideRect(
Rect rect) → bool -
inherited
-
lastChild<
T extends Component> () → T? -
Returns the last child that matches the given type
T, or null if there are no such children.inherited -
localToParent(
Vector2 point, {Vector2? output}) → Vector2 -
inherited
-
lookAt(
Vector2 target) → void -
Rotates/snaps the component to look at the
target.inherited -
makeOpaque(
{Object? paintId}) → void -
Manipulate the paint to make it fully opaque.
inherited
-
makeTransparent(
{Object? paintId}) → void -
Manipulate the paint to make it fully transparent.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChildrenChanged(
Component child, ChildrenChangeType type) → void -
This method will be invoked from lifecycle if
childhas been added to or removed from its parent children list.inherited -
onCollision(
Set< Vector2> intersectionPoints, ShapeHitbox other) → void -
onCollision is called in every tick when this object is colliding with
other.inherited -
onCollisionEnd(
ShapeHitbox other) → void -
onCollisionEnd is called once when this object has stopped colliding
with
other.inherited -
onCollisionStart(
Set< Vector2> intersectionPoints, ShapeHitbox other) → void -
onCollisionStart is called in the first tick when this object starts
colliding with
other.inherited -
onComponentTypeCheck(
PositionComponent other) → bool -
Defines whether the
othercomponent should be able to collide with this component.inherited -
onGameResize(
Vector2 size) → void -
Called whenever the size of the top-level Canvas changes.
inherited
-
onHotReload(
) → void -
Called when Flutter's hot reload is triggered.
inherited
-
onLoad(
) → FutureOr< void> -
Late initialization method for
Component.inherited -
onMount(
) → void -
Called when the component is added to its parent.
inherited
-
onParentResize(
Vector2 maxSize) → void -
Called whenever the parent of this component changes size; and also once
before onMount.
inherited
-
onParentSpeedChange(
) → void -
inherited
-
onRemove(
) → void -
Called right before the component is removed from its parent
and also before it changes parents (and is thus temporarily removed
from the component tree).
inherited
-
opacityProviderOf(
Object paintId) → OpacityProvider -
Creates an
OpacityProviderfor givenpaintIdand can be used astargetforOpacityEffect.inherited -
opacityProviderOfList(
{List< Object?> ? paintIds, bool includeLayers = true}) → OpacityProvider -
Creates an
OpacityProviderfor given list ofpaintIdsand can be used astargetforOpacityEffect.inherited -
parentToLocal(
Vector2 point, {Vector2? output}) → Vector2 -
inherited
-
positionOf(
Vector2 point) → Vector2 -
Convert local coordinates of a point
pointinside the component into the parent's coordinate space.inherited -
positionOfAnchor(
Anchor anchor) → Vector2 -
Similar to positionOf(), but applies to any anchor point within
the component.
inherited
-
possibleIntersectionVertices(
Rect? rect) → List< LineSegment> -
Return all vertices as
LineSegments that intersectrect, ifrectis null return all vertices asLineSegments.inherited -
possiblyIntersects(
ShapeHitbox other) → bool -
Since this is a cheaper calculation than checking towards all shapes, this
check can be done first to see if it even is possible that the shapes can
overlap, since the shapes have to be within the size of the component.
inherited
-
propagateToChildren<
T extends Component> (bool handler(T), {bool includeSelf = false}) → bool -
This method first calls the passed handler on the leaves in the tree,
the children without any children of their own.
Then it continues through all other children. The propagation continues
until the handler returns false, which means "do not continue", or when
the handler has been called with all children.
inherited
-
pureTypeCheck(
Type other) → bool -
Perform type check between:
inherited
-
rayIntersection(
Ray2 ray, {RaycastResult< ShapeHitbox> ? out}) → RaycastResult<ShapeHitbox> ? -
Returns whether the
RaycastResultif therayintersects the polygon.inherited -
rebalanceChildren(
) → void -
inherited
-
refreshVertices(
{required List< Vector2> newVertices, bool? shrinkToBoundsOverride}) → void -
inherited
-
remove(
Component component) → void -
Removes a component from the component tree.
inherited
-
removeAll(
Iterable< Component> components) → void -
Removes all the children in the list and calls
onRemovefor all of them and their children.inherited -
removeBroadphaseCheckItem(
ShapeHitbox item) → void -
inherited
-
removeFromParent(
) → void -
Remove the component from its parent in the next tick.
inherited
-
removeWhere(
bool test(Component component)) → void -
Removes all the children for which the
testfunction returns true.inherited -
render(
Canvas canvas) → void -
inherited
-
renderChild(
Canvas canvas, Component child) → void -
Renders a single
childcomponent ontocanvas.inherited -
renderDebugMode(
Canvas canvas) → void -
inherited
-
renderTree(
Canvas canvas) → void -
inherited
-
setAlpha(
int alpha, {Object? paintId}) → void -
Changes the opacity of the paint.
inherited
-
setByRect(
Rect rect) → void -
Mutates position and size using the provided
rectas basis. This is a relative rect, same definition thattoRectuse (therefore both methods are compatible, i.e. setByRect ∘ toRect = identity).inherited -
setColor(
Color color, {Object? paintId}) → void -
Shortcut for changing the color of the paint.
inherited
-
setOpacity(
double opacity, {Object? paintId}) → void -
Changes the opacity of the paint.
inherited
-
setPaint(
Object paintId, Paint paint) → void -
Sets a paint on the collection.
inherited
-
storeBroadphaseCheckCache(
ShapeHitbox item, bool canCollide) → void -
inherited
-
storeBroadphaseCheckCache(
ShapeHitbox item, bool canCollide) → void -
Available on ShapeHitbox, provided by the SpatialGridShapeHitbox extension
-
tint(
Color color, {Object? paintId}) → void -
Applies a color filter to the paint which will make
things rendered with the paint looking like it was
tinted with the given color.
inherited
-
toAbsoluteRect(
) → Rect -
The bounding rectangle of the component in global coordinate space.
inherited
-
toLocal(
Vector2 point) → Vector2 -
Transform
pointfrom the parent's coordinate space into the local coordinates. This function is the inverse of positionOf().inherited -
toRect(
) → Rect -
Returns the bounding rectangle for this component.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
double dt) → void -
This method is called periodically by the game engine to request that your
component updates itself.
inherited
-
updateTree(
double dt) → void -
This method traverses the component tree and calls
updateon all its children according to theirpriorityorder, relative to the priority of the direct siblings, not the children or the ancestors.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited